from pkg_resources import get_distribution

__version__ = get_distribution('baseEmoji').version

from .baseEmoji import encode
from .baseEmoji import encodeStr
from .baseEmoji import decode
from .baseEmoji import decodeStr


from setuptools import setup, find_packages

setup(
    name="baseEmoji",
    version = '0.0.4',
    description="A simple base1024 encoder that outputs emoji.",
    long_description='baseEmoji is a base1024 encoding scheme that uses emoji as its lookup table. The primary purpose is to represent otherwise ugly data in more "pleasing" form in social media.',
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 2.7"
    ],
    keywords="base1024 encode emoji",
    author="Ben Craton",
    author_email="tsunaminoai@gmail.com",
    url="http://github.com/tsunaminoai/baseemoji",
    license="MIT",
    packages=find_packages(exclude=["test",]),
    namespace_packages=[],
    include_package_data=False,
    zip_safe=False,
    install_requires=[
        "uniseg",
    ],
    tests_require=[],
    test_suite="test"
)



# -*- coding: utf-8 -*-

import baseEmoji
import unittest
import random
import string

class baseEmojiTest(unittest.TestCase):
    def testEncodeDecodeInt(self):
      for i in range(100):
        test_int = random.getrandbits(128)
        encoded_string = baseEmoji.encode(test_int)
        decoded_int = baseEmoji.decode(encoded_string)
        self.assertEqual(test_int, decoded_int, "Failed on %d" % test_int)

    def testEncodeDecodeString(self):
        for i in range(100):
            test_string = ''.join(random.choice(string.printable) for _ in range(random.randint(10,140)))
            encoded_string = baseEmoji.encodeStr(test_string)
            decoded_string = baseEmoji.decodeStr(encoded_string)
            self.assertEqual(test_string, decoded_string, "Failed on %s" % test_string)


    def testEncodeDecodeStringWithSpacing(self):
        test_string = ''.join(random.choice(string.printable) for _ in range(random.randint(10,140)))
        encoded_string = baseEmoji.encodeStr(test_string," ")
        decoded_string = baseEmoji.decodeStr(encoded_string," ")
        self.assertEqual(test_string, decoded_string, "Failed on %s" % test_string)

    def testEncodeDecodeIntWithSpacing(self):
        test_int = random.getrandbits(128)
        encoded_string = baseEmoji.encode(test_int," ")
        decoded_int = baseEmoji.decode(encoded_string," ")
        self.assertEqual(test_int, decoded_int, "Failed on %d" % test_int)